|Travis CI Status|

-----------------------------------------------------------------------------------------------------

The javabridge Python package makes it easy to start a Java virtual
machine (JVM) from Python and interact with it. Python code can
interact with the JVM using a low-level API or a more convenient
high-level API.

PyPI record: https://pypi.python.org/pypi/javabridge

Documentation: http://pythonhosted.org/javabridge/

GitHub repository: https://github.com/CellProfiler/python-javabridge

Report bugs here: https://github.com/CellProfiler/python-javabridge/issues

python-javabridge is licensed under the BSD license.  See the
accompanying file LICENSE for details.

Copyright (c) 2003-2009 Massachusetts Institute of Technology
Copyright (c) 2009-2013 Broad Institute
All rights reserved.


.. |Travis CI Status| image:: https://travis-ci.org/CellProfiler/python-javabridge.svg?branch=master
   :target: https://travis-ci.org/CellProfiler/python-javabridge
